Pricing - OpenAI API
Description: Pricing for the OpenAI API.

Sign up
Cookbook
Forum

# Pricing

### Latest models

Text tokens
Price per /1M tokens
Batch API price

Model | Input | Cached input | Output
--- | --- | --- | ---
gpt-4.5-preview gpt-4.5-preview-2025-02-27 | $75.00 | $37.50 | $150.00
gpt-4o gpt-4o-2024-08-06 | $2.50 | $1.25 | $10.00
gpt-4o-audio-preview gpt-4o-audio-preview-2024-12-17 | $2.50 | - | $10.00
gpt-4o-realtime-preview gpt-4o-realtime-preview-2024-12-17 | $5.00 | $2.50 | $20.00
gpt-4o-mini gpt-4o-mini-2024-07-18 | $0.15 | $0.075 | $0.60
gpt-4o-mini-audio-preview gpt-4o-mini-audio-preview-2024-12-17 | $0.15 | - | $0.60
gpt-4o-mini-realtime-preview gpt-4o-mini-realtime-preview-2024-12-17 | $0.60 | $0.30 | $2.40
o1 o1-2024-12-17 | $15.00 | $7.50 | $60.00
o3-mini o3-mini-2025-01-31 | $1.10 | $0.55 | $4.40
o1-mini o1-mini-2024-09-12 | $1.10 | $0.55 | $4.40
gpt-4o-mini-search-preview gpt-4o-mini-search-preview-2025-03-11 | $0.15 | - | $0.60
gpt-4o-search-preview gpt-4o-search-preview-2025-03-11 | $2.50 | - | $10.00
computer-use-preview computer-use-preview-2025-03-11 | $3.00 | - | $12.00

Audio tokens
Price per /1M tokens

Model | Input | Cached input | Output
--- | --- | --- | ---
gpt-4o-audio-preview gpt-4o-audio-preview-2024-12-17 | $40.00 | - | $80.00
gpt-4o-mini-audio-preview gpt-4o-mini-audio-preview-2024-12-17 | $10.00 | - | $20.00
gpt-4o-realtime-preview gpt-4o-realtime-preview-2024-12-17 | $40.00 | $2.50 | $80.00
gpt-4o-mini-realtime-preview gpt-4o-mini-realtime-preview-2024-12-17 | $10.00 | $0.30 | $20.00

### Fine tuning

Price per /1M tokens
Batch API price

Model | Training | Input | Cached input | Output
--- | --- | --- | --- | ---
gpt-4o-2024-08-06 | $25.00 | $3.75 | $1.875 | $15.00
gpt-4o-mini-2024-07-18 | $3.00 | $0.30 | $0.15 | $1.20
gpt-3.5-turbo | $8.00 | $3.00 | - | $6.00
davinci-002 | $6.00 | $12.00 | - | $12.00
babbage-002 | $0.40 | $1.60 | - | $1.60

### Built-in tools

The tokens used for built-in tools are billed at the chosen model's per-token rates. GB refers to binary gigabytes of storage (also known as gibibyte), where 1GB is 2^30 bytes.

Tool | Cost
--- | ---
Code Interpreter | $0.03 session
File Search Storage | $0.10 GB/day (1GB free)
File Search Tool Call (Responses API only*) | $2.50 1k calls (*Does not apply on Assistants API)
Web Search | Pricing depends on model and search context size. See details below.

### Web search

Web search is a built-in tool with pricing that depends on both the model used and the search context size.

Model | Search context size | Cost
--- | --- | ---
gpt-4o or gpt-4o-search-preview | low | $30.00 1k calls
medium (default) | $35.00 1k calls
high | $50.00 1k calls
gpt-4o-mini or gpt-4o-mini-search-preview | low | $25.00 1k calls
medium (default) | $27.50 1k calls
high | $30.00 1k calls

### Transcription and speech generation

Model | Use case | Cost
--- | --- | ---
Whisper | Transcription | $0.006 minute
TTS | Speech generation | $15.00 1M characters
TTS HD | Speech generation | $30.00 1M characters

### Image generation

Price per /image

Model | Quality | 1024x1024 | 1024x1792
--- | --- | --- | ---
DALL·E 3 | Standard | $0.04 | $0.08
HD | $0.08 | $0.12
Model | 256x256 | 512x512 | 1024x1024
DALL·E 2 | $0.016 | $0.018 | $0.02

### Embeddings

Price per /1M tokens
Batch API price

Model | Cost
--- | ---
text-embedding-3-small | $0.02
text-embedding-3-large | $0.13
text-embedding-ada-002 | $0.10

### Moderation

Model | Cost
--- | ---
omni-moderation-latest omni-moderation-2024-09-26 | Free
text-moderation-latest text-moderation-007 | Free

### Other models

Price per /1M tokens
Batch API price

Model | Input | Output
--- | --- | ---
chatgpt-4o-latest | $5.00 | $15.00
gpt-4-turbo gpt-4-turbo-2024-04-09 | $10.00 | $30.00
gpt-4 gpt-4-0613 | $30.00 | $60.00
gpt-4-32k | $60.00 | $120.00
gpt-3.5-turbo gpt-3.5-turbo-0125 | $0.50 | $1.50
gpt-3.5-turbo-instruct | $1.50 | $2.00
gpt-3.5-turbo-16k-0613 | $3.00 | $4.00
davinci-002 | $2.00 | $2.00
babbage-002 | $0.40 | $0.40

We use cookies and similar technologies to deliver, maintain, improve our services and for security purposes. Check our Cookie Policy for details. Click 'Accept all' to let OpenAI and partners use cookies for these purposes. Click 'Reject all' to say no to cookies, except those that are strictly necessary. Choose 'Manage Cookies' to pick specific cookies you're okay with or to change your preferences.